@@ -421,6 +421,8 @@ brasero_checksum_files_merge_with_former_session (BraseroChecksumFiles *self,
 	burner = brasero_medium_get_drive (medium);
 	device = brasero_drive_get_device (burner);
 	dev_handle = brasero_device_handle_open (device, FALSE, NULL);
+	if (!dev_handle)
+		return BRASERO_BURN_ERR;
 
 	vol = brasero_volume_source_open_device_handle (dev_handle, error);
 	file = brasero_volume_get_file (vol,
@@ -841,6 +843,9 @@ brasero_checksum_files_check_files (BraseroChecksumFiles *self,
 
 	device = brasero_drive_get_device (brasero_medium_get_drive (medium));
 	dev_handle = brasero_device_handle_open (device, FALSE, NULL);
+	if (!dev_handle)
+		return BRASERO_BURN_ERROR;
+
 	vol = brasero_volume_source_open_device_handle (dev_handle, error);
 
 	/* open checksum file */
@@ -1475,15 +1480,13 @@ brasero_checksum_files_export_caps (BraseroPlugin *plugin)
 			       "Philippe Rouquier",
 			       0);
 
-	/* we can only generate a file for DATA input */
+	/* only generate a file for DATA input */
 	input = brasero_caps_data_new (BRASERO_IMAGE_FS_ANY);
 	brasero_plugin_process_caps (plugin, input);
 	g_slist_free (input);
 
-	/* we can run on initial track or later for whatever a DATA track */
-	brasero_plugin_set_process_flags (plugin,
-					  BRASERO_PLUGIN_RUN_PREPROCESSING|
-					  BRASERO_PLUGIN_RUN_BEFORE_TARGET);
+	/* run on initial track for whatever a DATA track */
+	brasero_plugin_set_process_flags (plugin, BRASERO_PLUGIN_RUN_PREPROCESSING);
 
 	/* For discs, we can only check each files on a disc against an md5sum 
 	 * file (provided we managed to mount the disc).
